package com.example.examsimplecrud

import android.os.Bundle
import android.widget.Button
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.RecyclerView
import com.example.examsimplecrud.adapters.WeatherForecastAdapter
import com.example.examsimplecrud.models.WeatherForecastViewModel
import com.example.examsimplecrud.services.WeatherApi
import kotlinx.coroutines.runBlocking

class MainActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val forecastsView = findViewById<RecyclerView>(R.id.forecasts)
        val forecasts: List<WeatherForecastViewModel>

        runBlocking {
            forecasts = getWeatherForecast()
        }

        val adapter = WeatherForecastAdapter(this, forecasts)
        forecastsView.adapter = adapter

        val dateSortBtn = findViewById<Button>(R.id.dateSort)
        val temperatureSortBtn = findViewById<Button>(R.id.temperatureSort)

        var dateSortBtnClicked = false;
        dateSortBtn.setOnClickListener(){
            val items = if (dateSortBtnClicked){
                forecasts.sortedByDescending { f -> f.date }
            } else {
                forecasts.sortedBy { f -> f.date }
            }

            dateSortBtnClicked = !dateSortBtnClicked
            forecastsView.adapter = WeatherForecastAdapter(this, items)
        }

        var temperatureSortBtnClicked = false;
        temperatureSortBtn.setOnClickListener(){
            val items = if (temperatureSortBtnClicked){
                forecasts.sortedByDescending { f -> f.temperatureC }
            } else {
                forecasts.sortedBy { f -> f.temperatureC }
            }

            temperatureSortBtnClicked = !temperatureSortBtnClicked
            forecastsView.adapter = WeatherForecastAdapter(this, items)
        }
    }

    private suspend fun getWeatherForecast(): List<WeatherForecastViewModel> {
        return WeatherApi.retrofitWeatherService.getWeatherForecast()
    }
}